==> task-3.30.1.tar.gz: task-3.30.1/docs/i18n/pt-BR/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# Doe

Se você acha esse projeto útil, considere doar usando um dos meios listados abaixo.

Esta é apenas uma maneira de dizer "obrigado", ele não lhe dará nenhum benefício como maior prioridade em issues ou algo parecido.

As empresas que doarem pelo menos $50/mês ganharão destaque como "Patrocinador Ouro" na página do site e no README do repositório no GitHub. Faça contato com [@andreynering][] com o logotipo que você deseja ser mostrado no site. Negócios suspeitos (apostas, cassinos, etc) não serão permitidos, porém.

## GitHub Sponsors

A forma sugerida de doar para os mantenedores é através do GitHub Sponsors. Basta usar os seguintes links para fazer a sua doação:

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

Se você preferir o [Open Collective](https://opencollective.com/task) você pode doar usando um destes links:

- [$2 por mês](https://opencollective.com/task/contribute/backer-4034/checkout)
- [$5 por mês](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [$20 por mês](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [$50 por mês](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Valor personalizado - Essa opção também suporta doar uma única vez](https://opencollective.com/task/donate)

## PayPal

Você pode doar para [@andreynering][] através do PayPal também:

- [Qualquer valor - Doação única](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (somente para o Brasil)

E se você é brasileiro, também pode doar para [@andreynering][] via PIX [usando este QR Code](/img/pix.png).

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering

==> task-3.34.0.tar.gz: task-3.34.0/docs/i18n/pt-BR/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# Doe

Se você acha esse projeto útil, considere doar usando um dos meios listados abaixo.

Esta é apenas uma maneira de dizer "obrigado", ele não lhe dará nenhum benefício como maior prioridade em issues ou algo parecido.

As empresas que doarem pelo menos $50/mês ganharão destaque como "Patrocinador Ouro" na página do site e no README do repositório no GitHub. Faça contato com [@andreynering][] com o logotipo que você deseja ser mostrado no site. Negócios suspeitos (apostas, cassinos, etc) não serão permitidos, porém.

## GitHub Sponsors

A forma sugerida de doar para os mantenedores é através do GitHub Sponsors. Just use the following links to do your donation. We suggest a 50/50 split to each maintainer of the total amount you plan to donate to the project.

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

Se você preferir o [Open Collective](https://opencollective.com/task) você pode doar usando um destes links:

- [$2 por mês](https://opencollective.com/task/contribute/backer-4034/checkout)
- [$5 por mês](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [$20 por mês](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [$50 por mês](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Valor personalizado - Essa opção também suporta doar uma única vez](https://opencollective.com/task/donate)

## PayPal

Você pode doar para [@andreynering][] através do PayPal também:

- [Qualquer valor - Doação única](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (somente para o Brasil)

E se você é brasileiro, também pode doar para [@andreynering][] via PIX [usando este QR Code](/img/pix.png).

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering
